package com.akamai.ampdemo;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String TAG = "AMPv6";
    private final static String LICENSE = "BtvXWK8rlDMO8uWHJcnKB84uPUOQYCI8UKi9jGUgG5aGrKCdiKOsFVA00spK8fs7WDdZ9qNk5ztdMn1yWiam1g==";
    private final static String VIDEO_URL = "http://sblancovodmdev-f.akamaihd.net/i/temp/bbb.mp4/master.m3u8";


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;

    private MediaResource resource;

    private boolean mWasPlaying = false;
    private int mCurrentPosition = 0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(VIDEO_URL);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        resource = mediaResource;

        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setProgressBarControl(progressBar);
        videoPlayerView.setLicense(LICENSE);
        videoPlayerView.setFullScreen(true);
        videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
        videoPlayerView.setLogEnabled(true);

        videoPlayerView.play(resource, mCurrentPosition);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError() {
        Log.e(TAG, "onResourceError()");
    }

    @Override
    protected void onResume() {
        Log.d(TAG, "onResume");

        if (mWasPlaying) {
            videoPlayerView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(TAG, "onPause");

        boolean shouldStop = (videoPlayerView != null) && (videoPlayerView.isPlaying() || videoPlayerView.isPaused());
        if (shouldStop) {
            mCurrentPosition = videoPlayerView.getTimePosition();
            mWasPlaying = true;
            videoPlayerView.stop();
        }

        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "onDestroy");

        videoPlayerView.stop();
        videoPlayerView.onDestroy();
        super.onDestroy();
    }

}
