package fragment;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import com.akamai.captioning.CaptionComponent;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class WebVTTFragment extends android.support.v4.app.Fragment
        implements View.OnTouchListener, IPlayerEventsListener {

    private final static String TAG = "AMP-CC-WEBVTT";
    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,.f4v.csmil/master.m3u8";
    private final static String CAPTION_ASSET_URL = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/sample.vtt";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoPlayerView;
    private ProgressBar mProgressBar;


    private CaptionComponent captionComponent;


    public static WebVTTFragment newInstance() {
        WebVTTFragment fragment = new WebVTTFragment();
        return fragment;
    }

    public WebVTTFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {

        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        captionComponent = (CaptionComponent) rootView.findViewById(R.id.captionView);

        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                mVideoPlayerView = mVideoContainer.getVideoPlayer();
                mVideoPlayerView.setProgressBarControl(mProgressBar);
                mVideoPlayerView.setLicense(MainActivity.LICENSE);

                mVideoPlayerView.setFullScreen(true);
                mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                mVideoPlayerView.setLogEnabled(true);

                initCaptions();

                mVideoPlayerView.addEventsListener(WebVTTFragment.this);
                mVideoPlayerView.setKeepScreenOn(true);
                mVideoPlayerView.setOnTouchListener(WebVTTFragment.this);

                mVideoPlayerView.play(mediaResource);
            }

            @Override
            public void onResourceError() {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);

        return rootView;
    }

    /**
     * Caption configuration
     */
    private void initCaptions(){
        captionComponent.setVideoPlayerView(mVideoPlayerView);
        captionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_DROP_SHADOW_STYLE);
        captionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_TOP);
        captionComponent.setTextSize(18);
        captionComponent.setTextBackgroundColor(Color.BLACK);
        captionComponent.setTextColor(Color.WHITE);
        captionComponent.setTextWindowColor(Color.GREEN);
        captionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_POP_ON);

        // External VTT file, for media assets with no integrated captions
        captionComponent.loadExternalVTTResource("English", "en", CAPTION_ASSET_URL);
    }

    @Override
    public void onResume() {
        Log.d(TAG, "OnResume");
        if (mVideoPlayerView != null) {
            mVideoPlayerView.resume();
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d(TAG, "OnPause");
        if(mVideoPlayerView != null){
            mVideoPlayerView.pause();
        }
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d(TAG, "OnDestroy");
        if (mVideoPlayerView!=null) {
            mVideoPlayerView.stop();
            mVideoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d(TAG, "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }

}